.. raw:: html

    <style> .red {color:red} </style>
    <style> .blue {color:blue} </style>
    <style> .green {color:green} </style>
    <style> .cyan {color:cyan} </style>
    <style> .magenta {color:magenta} </style>
    <style> .orange {color:orange} </style>
    <style> .brown {color:brown} </style>

.. role:: red
.. role:: blue
.. role:: green
.. role:: cyan
.. role:: magenta
.. role:: orange
.. role:: brown
.. default-role:: py:obj

.. _v2blocks:

The following classes implement different MDF version 3 blocks.

Channel Class
^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.Channel


ChannelConversion Class
^^^^^^^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.ChannelConversion

ChannelDependency Class
^^^^^^^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.ChannelDependency

ChannelExtension Class
^^^^^^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.ChannelExtension

ChannelGroup Class
^^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.ChannelGroup

DataGroup Class
^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.DataGroup

FileIdentificationBlock Class
^^^^^^^^^^^^^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.FileIdentificationBlock

HeaderBlock Class
^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.HeaderBlock

ProgramBlock Class
^^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.ProgramBlock

TextBlock Class
^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.TextBlock

TriggerBlock Class
^^^^^^^^^^^^^^^^^^
.. autoclass:: asammdf.blocks.v2_v3_blocks.TriggerBlock
